==> haskell-http-streams-0.8.6.1-130-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-http-streams.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: http-streams
version: 0.8.6.1
id: http-streams-0.8.6.1-92lL5ICNCin20AvvxeApFD
key: http-streams-0.8.6.1-92lL5ICNCin20AvvxeApFD
license: BSD-3-Clause
copyright: © 2012-2018 Operational Dynamics Consulting, Pty Ltd and Others
maintainer: Andrew Cowie <andrew@operationaldynamics.com>
author: Andrew Cowie <andrew@operationaldynamics.com>
stability: experimental
homepage: https://github.com/afcowie/http-streams/
synopsis: An HTTP client using io-streams
description:
    /Overview/
    .
    An HTTP client, using the Snap Framework'\''s '\''io-streams'\'' library to
    hande the streaming IO. The API is optimized for ease of use for the
    rather common case of code needing to query web services and deal with
    the result.
    .
    The library is exported in a single module; see "Network.Http.Client"
    for full documentation.
category: Web, IO-Streams
abi: 8c993664141a107b6d437b854c76924e
exposed: True
exposed-modules:
    Network.Http.Client Network.Http.Connection
    Network.Http.Inconvenience Network.Http.ResponseParser
hidden-modules: Network.Http.Utilities
import-dirs: /usr/lib/ghc-8.6.5/site-local/http-streams-0.8.6.1
library-dirs: /usr/lib/ghc-8.6.5/site-local/http-streams-0.8.6.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/http-streams-0.8.6.1
hs-libraries: HShttp-streams-0.8.6.1-92lL5ICNCin20AvvxeApFD
depends:
    HsOpenSSL-0.11.4.16-AIig2KA3voy15d9QgBOX55
    aeson-1.4.4.0-KwovUsQGNt8PPlzoq6sTW
    attoparsec-0.13.2.2-JtccVfLzqCgD0Y1SyaKt8t base-4.12.0.0
    base64-bytestring-1.0.0.2-C0hiEzqCknwIpHHXqmcpJo
    blaze-builder-0.4.1.0-KrFxFv3kgua3BTNMsMBadC bytestring-0.10.8.2
    case-insensitive-1.2.1.0-L7BR5PaOPZy5cAHpLYQKhk directory-1.3.3.0
    http-common-0.8.2.0-32ugCzeZSErAewkdOazL2h
    io-streams-1.5.1.0-46RQH784My91OHHMmubhfr mtl-2.2.2
    network-2.8.0.0-HTKosw7lwpaCVnkz1nc19d
    network-uri-2.6.1.0-K75fCYvLQE41EntOQ30cqK
    openssl-streams-1.2.2.0-59L0dOuVtDrEivhRbjwhbt text-1.2.3.1
    transformers-0.5.6.2
    unordered-containers-0.2.10.0-1NpUw7eLrexDi5zNhT27CT
haddock-interfaces: /usr/share/doc/haskell-http-streams/html/http-streams.haddock
haddock-html: /usr/share/doc/haskell-http-streams/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-http-streams-0.8.6.1-132-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-http-streams.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: http-streams
version: 0.8.6.1
id: http-streams-0.8.6.1-HDLq3NMHXfY9ueJI0JWRkZ
key: http-streams-0.8.6.1-HDLq3NMHXfY9ueJI0JWRkZ
license: BSD-3-Clause
copyright: © 2012-2018 Operational Dynamics Consulting, Pty Ltd and Others
maintainer: Andrew Cowie <andrew@operationaldynamics.com>
author: Andrew Cowie <andrew@operationaldynamics.com>
stability: experimental
homepage: https://github.com/afcowie/http-streams/
synopsis: An HTTP client using io-streams
description:
    /Overview/
    .
    An HTTP client, using the Snap Framework'\''s '\''io-streams'\'' library to
    hande the streaming IO. The API is optimized for ease of use for the
    rather common case of code needing to query web services and deal with
    the result.
    .
    The library is exported in a single module; see "Network.Http.Client"
    for full documentation.
category: Web, IO-Streams
abi: 3930c6383cfa6bae5fab4c985e04ba15
exposed: True
exposed-modules:
    Network.Http.Client Network.Http.Connection
    Network.Http.Inconvenience Network.Http.ResponseParser
hidden-modules: Network.Http.Utilities
import-dirs: /usr/lib/ghc-8.6.5/site-local/http-streams-0.8.6.1
library-dirs: /usr/lib/ghc-8.6.5/site-local/http-streams-0.8.6.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/http-streams-0.8.6.1
hs-libraries: HShttp-streams-0.8.6.1-HDLq3NMHXfY9ueJI0JWRkZ
depends:
    HsOpenSSL-0.11.4.16-AIig2KA3voy15d9QgBOX55
    aeson-1.4.4.0-KwovUsQGNt8PPlzoq6sTW
    attoparsec-0.13.2.2-JtccVfLzqCgD0Y1SyaKt8t base-4.12.0.0
    base64-bytestring-1.0.0.2-C0hiEzqCknwIpHHXqmcpJo
    blaze-builder-0.4.1.0-KrFxFv3kgua3BTNMsMBadC bytestring-0.10.8.2
    case-insensitive-1.2.1.0-L7BR5PaOPZy5cAHpLYQKhk directory-1.3.3.0
    http-common-0.8.2.0-32ugCzeZSErAewkdOazL2h
    io-streams-1.5.1.0-46RQH784My91OHHMmubhfr mtl-2.2.2
    network-2.8.0.0-HTKosw7lwpaCVnkz1nc19d
    network-uri-2.6.1.0-K75fCYvLQE41EntOQ30cqK
    openssl-streams-1.2.2.0-59L0dOuVtDrEivhRbjwhbt text-1.2.3.1
    transformers-0.5.6.2
    unordered-containers-0.2.10.0-1NpUw7eLrexDi5zNhT27CT
haddock-interfaces: /usr/share/doc/haskell-http-streams/html/http-streams.haddock
haddock-html: /usr/share/doc/haskell-http-streams/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
